@@ -1,7 +1,11 @@
 import os
+import shlex
+
 from enum import Enum
 from tempfile import NamedTemporaryFile
 
+import platform
+
 from click import BadParameter
 
 
@@ -39,3 +43,23 @@ def get_edited_prompt() -> str:
     if not output:
         raise BadParameter("Couldn't get valid PROMPT from $EDITOR")
     return output
+
+
+def run_command(command: str) -> None:
+    """
+    Runs a command in the user's shell.
+    It is aware of the current user's $SHELL.
+    :param command: A shell command to run.
+    """
+    if platform.system() == "Windows":
+        is_powershell = len(os.getenv("PSModulePath", "").split(os.pathsep)) >= 3
+        full_command = (
+            f'powershell.exe -Command "{command}"'
+            if is_powershell
+            else f'cmd.exe /c "{command}"'
+        )
+    else:
+        shell = os.environ.get("SHELL", "/bin/sh")
+        full_command = f"{shell} -c {shlex.quote(command)}"
+
+    os.system(full_command)
